Learn R Programming

scholar (version 1.0.0)

get_coauthors: Gets the network of coauthors of a scholar

Description

Gets the network of coauthors of a scholar

Usage

get_coauthors(id, n_coauthors = 5, n_deep = 1)

Value

A data frame with two columns showing all authors and coauthors.

Arguments

id

a character string specifying the Google Scholar ID. If multiple ids are specified, only the first value is used and a warning is generated.

n_coauthors

Number of coauthors to explore. This number should usually be between 1 and 10 as choosing many coauthors can make the network graph too messy.

n_deep

The number of degrees that you want to go down the network. When n_deep is equal to 1 then grab_coauthor will only grab the coauthors of Joe and Mary, so Joe -- > Mary --> All coauthors. This can get out of control very quickly if n_deep is set to 2 or above. The preferred number is 1, the default.

Details

Considering that scraping each publication for all coauthors is error prone, get_coauthors grabs the coauthors listed by Google Scholar for the profile, not from all publications. It first tries Google Scholar's full colleagues list and falls back to the profile sidebar if that list is unavailable.

See Also

plot_coauthors

Examples

Run this code

if (FALSE) {

library(scholar)
coauthor_network <- get_coauthors('amYIKXQAAAAJ')
plot_coauthors(coauthor_network)
}


Run the code above in your browser using DataLab