Description Usage Arguments Value Author(s) Examples
Get journal metrics (impact factor) for a journal list.
1 | get_impactfactor(journals, max.distance = 0.05)
|
journals |
a character list giving the journal list |
max.distance |
maximum distance allowed for a match bewteen journal and journal list. Expressed either as integer, or as a fraction of the pattern length times the maximal transformation cost (will be replaced by the smallest integer not less than the corresponding fraction), or a list with possible components |
Journal metrics data.
Dominique Makowski and Guangchuang Yu
1 2 3 4 5 6 | library(scholar)
id <- get_publications("bg0BZ-QAAAAJ&hl")
impact <- get_impactfactor(journals=id$journal, max.distance = 0.1)
id <- cbind(id, impact)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.