Learn R Programming

scholar (version 1.0.0)

get_journalrank: Get journal ranking.

Description

Get SCImago journal ranking data.

Usage

get_journalrank(journals, max.distance = 0.05)

Value

Journal ranking data.

Arguments

journals

a character list giving the journal list. If missing, the full SCImago journal ranking table is returned.

max.distance

maximum distance allowed for a match between journal and journal list. Expressed either as integer, or as a fraction of the pattern length times the maximal transformation cost (will be replaced by the smallest integer not less than the corresponding fraction), or a list with possible components

Author

Dominique Makowski and Guangchuang Yu

Examples

Run this code
if (FALSE) {
library(scholar)

id <- get_publications("bg0BZ-QAAAAJ&hl")
impact <- get_journalrank(journals=id$journal)

id <- cbind(id, impact)
}

Run the code above in your browser using DataLab