Learn R Programming

scholar (version 1.0.0)

get_oldest_article: Gets the year of the oldest article for a scholar

Description

Gets the year of the oldest article published by a given scholar.

Usage

get_oldest_article(id)

Value

the year of the oldest article

Arguments

id

a character string giving the Google Scholar ID