Learn R Programming

scholar (version 1.0.0)

get_publications_all_authors: Gets publications with complete author lists

Description

Gets a scholar's publications and fills truncated author lists by calling get_complete_authors only for publications whose author field contains ....

Usage

get_publications_all_authors(id, delay = 0.8, initials = TRUE, ...)

Value

a data frame listing the publications and their details, with truncated author lists replaced where possible.

Arguments

id

a character string specifying the Google Scholar ID.

delay

average delay between requests for complete author lists. See get_complete_authors.

initials

if TRUE, first and middle names in completed author lists will be abbreviated. See get_complete_authors.

...

additional arguments passed to get_publications.