The scholar package provides functions to extract citation data from
Google Scholar. There are also convenience functions for comparing multiple
scholars and predicting h-index scores based on past publication records.
Google does not encourage people to use the scholar website as an API. You will find a number of issues related to this if you follow: https://github.com/jkeirstead/scholar/issues?q=is:issue+cookie
If you try to fetch too many pages, you can expect to see your access to
scholar blocked. One step that they do take is to provide a session cookie.
Reusing these seems to help. If you wish to write your own code to interact
with Google Scholar, we recommend that you use the
get_scholar_resp function to carry out the query.
Maintainer: Guangchuang Yu [email protected] (ORCID)
Authors:
Guangchuang Yu [email protected] (ORCID)
James Keirstead [email protected]
Gregory Jefferis [email protected] (ORCID)
Other contributors:
Gordon Getzinger [contributor]
Jorge Cimentada [email protected] [contributor]
Max Czapanskiy [email protected] [contributor]
Dominique Makowski [email protected] [contributor]
Useful links: