powered by
Searches Google Scholar author results and returns matching author IDs.
search_scholar_ids(name, max_pages = Inf, delay = 0)
a data frame with columns id, name, affiliation, email, interests, and url
id
name
affiliation
email
interests
url
author search query
maximum number of search result pages to fetch
number of seconds to wait between result pages
# \donttest{ search_scholar_ids("hao xu", max_pages = 1) # }
Run the code above in your browser using DataLab