a character list giving the journal list. If missing, the
full SCImago journal ranking table is returned.
max.distance
maximum distance allowed for a match between journal and journal list.
Expressed either as integer, or as a fraction of the pattern length times the maximal transformation cost
(will be replaced by the smallest integer not less than the corresponding fraction), or a list with possible components