Gets a scholar's publications and fills truncated author lists by calling
get_complete_authors only for publications whose author field
contains ....
get_publications_all_authors(id, delay = 0.8, initials = TRUE, ...)a data frame listing the publications and their details, with truncated author lists replaced where possible.
a character string specifying the Google Scholar ID.
average delay between requests for complete author lists. See
get_complete_authors.
if TRUE, first and middle names in completed author lists
will be abbreviated. See get_complete_authors.
additional arguments passed to get_publications.